<template>
  <gree-popup class="lr-Grid-set-popup" v-model="isShow" get-container="body" position="bottom" @hide="hidePopup">
    <div class="lr-Grid-set-popup">
      <p class="title" v-text="title" />
      <a class="tips" v-text="tips" />
      <btn-group :btn-list="btnList" />
    </div>
  </gree-popup>
</template>

<script>
import { Popup } from 'gree-ui';
import { mapMutations, mapActions, mapState, mapGetters } from 'vuex';
import { types } from '@/store/types';
import BtnGroup from '@/components/BtnGroup/index';
import CardGroup from '@/components/CardGroup/index';

export default {
  name: 'ConstLRGridSet',
  components: {
    [Popup.name]: Popup,
    [BtnGroup.name]: BtnGroup,
    [CardGroup.name]: CardGroup
  },
  data() {
    return {
      isShow: false
    };
  },
  computed: {
    ...mapState('control', {
      LRPicker: state => state.popup.LRPicker
    }),
    ...mapGetters(['swingLRModels']),
    ...mapGetters('machine', ['statusLoop', 'statusMap']),
    btnList() {
      const result = [];
      // console.log('swingLRModels', this.swingLRModels);
      this.swingLRModels.forEach(model => {
        const statusNameList = this.getLoop(model);
        statusNameList.forEach(statusName => {
          const { identifier } = model;
          const currentStatusName = this.getCurrentStatusName(identifier);
          const stateName = `${identifier}_${statusName}`;
          // status定义
          const status = model.statusDefine[statusName];
          // 名称
          const statusNameText = status.name;
          const stateNameText = this.$language(`${statusNameText}`);
          // 图标
          const icon = {
            key: status.icon.key,
            type: currentStatusName === statusName ? 'on' : 'off'
          };
          // 是否置灰
          const gray = false;
          // 是否隐藏
          const hide = status.icon.key === 'disable';
          // 跳转页面
          const page = false;
          // 执行的函数
          const handler = (_, disable = false) => {
            disable || this.$stateMachine.toStatus(identifier, statusName);
          };
          result.push({ key: stateName, name: stateNameText, icon, gray, hide, page, handler });
        });
      });
      return result;
    },
    title() {
      return this.$language('btn.ConstLRGrid');
    },
    tips() {
      return this.$language('ConstLR.tips');
    }
  },
  watch: {
    isShow(newVal) {
      !newVal && this.SetPopup({ LRPicker: false });
    },
    LRPicker: {
      handler(newVal) {
        this.isShow = newVal;
      },
      immediate: true
    }
  },
  methods: {
    ...mapMutations({
      setDataObject: types.SET_DATA_OBJECT,
      setState: types.CONTROL_SET_STATE
    }),
    ...mapMutations('control', {
      SetPopup: 'SET_POPUP'
    }),
    ...mapActions({
      sendCtrl: types.SEND_CTRL
    }),
    hidePopup() {
      this.SetPopup({ UpDnPicker: false });
    },
    getLoop(model) {
      if (!model) return [];
      const { identifier } = model;
      let result = JSON.parse(JSON.stringify(this.statusLoop[identifier]));
      const startStatusName = 'default';
      const defaultIndex = result.findIndex(statusName => statusName === startStatusName);
      result.unshift(...result.splice(defaultIndex));
      return result;
    },
    getCurrentStatusName(identifier) {
      return String(this.statusMap[identifier].statusName);
    }
  }
};
</script>

<style lang="scss">
.lr-Grid-set-popup {
  width: 100%;
  background-color: #fff;
  .title {
    padding-top: 30px;
    text-align: center;
    font-size: 50px;
  }
  .tips {
    padding-top: 10px;
    display: block;
    text-align: center;
    font-size: 32px;
    color: #989898;
  }
  // .btn-group {
  //   .row {
  //     .btn-col {
  //       .icon {
  //         // color: red;
  //       }
  //       &.select {
  //         .icon {
  //           // background-image: linear-gradient(rgb(141, 191, 253), rgb(119, 167, 224));
  //           // box-shadow: 0 9px 21px rgba(14, 110, 227, 0.15);
  //           i {
  //             // color: red;
  //           }
  //         }
  //       }
  //     }
  //   }
  // }
}
</style>
